Skip to main contentModule eval
Source - Context
- A binding of variables and functions used during evaluation.
- Func
- A built-in or user-defined single- or multi-argument math function.
- eval
- Evaluate
expr in the supplied ctx, returning f64. - eval_str
- Evaluate an expression string in the standard context, optionally
overriding variables through
vars (e.g., &[("x", "2.0")]).